function pdf = get_gauss_mixture(mu, N0)
% get_gauss_mixture returns function handle for the 2D pdf for gaussian mixture 
% r.v. , array mu contains mean values of mixture components, N0 is
% variance of mixture components
N = numel(mu); % number of mixture components
%% Complex Normal probability density function
%
% $$f_{\mathcal{N}(\mu, N_0)}(\theta) = \frac{1}{\pi \times N_0} e^{(\frac{\|\theta-\mu\|^2}{N_0})}$$
%
%% Gaussian Mixture probability density function
%
% $$f_{Mixture}(\theta) = \frac{1}{N}\sum_{n=1}^{N}f_{\mathcal{N}(\mu_i, N_0)}(\theta)$$
%
pdf = @gm;
    function f = gm(x, y)
        f = 0;
        for n = 1 : N
            f = f + exp(-((x-real(mu(n))).^2 + (y-imag(mu(n))).^2)/(N0));
        end
        f = f / (pi*N0);
        f = f / N;
    end

end